/* Copyright (C) Click & Push Accessibility, Inc - All Rights Reserved
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written and maintained by the Click & Push Development team 
 * <dev@clicknpush.ca>, January 2023
 */

import { FontAwesome } from "@expo/vector-icons"
import React, { useEffect } from "react"
import { useState } from "react"
import { Alert, Text, StyleSheet, Pressable, TextInput, TouchableOpacity, View, Keyboard } from "react-native"
import Modal from "react-native-modal"
import Select from "react-native-multiple-select"
import { LMComment } from "../../../../data/comments"
import { Landmark } from "../../../../data/landmarks"


interface ReportProps {
    landmark?: Landmark,
    comment?: LMComment
    isLandmark: boolean,
    // reportLandmark: (string) => void
}

export const Report: React.FC<ReportProps> = (props) => {

    const [keyboardIsVisible, setKeyboardIsVisible] = useState(false)
    useEffect(() => {
        const showListener = Keyboard.addListener("keyboardDidShow", () => {
            setKeyboardIsVisible(true)
        })
        const hideListener = Keyboard.addListener("keyboardDidHide", () => {
            setKeyboardIsVisible(false)
        })

        return () => {
            showListener.remove()
            hideListener.remove()
        }
    }, [])

    const toggleModal = () => {
        setModalVisible(!modalVisible)
    }

    const sendReport = () => {
        var report = props.isLandmark ?
            "Report submitted for landmark '" + props.landmark?.title + "':\n\tID: " + props.landmark?.id
            + "\n\tLandmark author: " + props.landmark?.user
            + "\n\tCoordinates: " + props.landmark?.longitude + " " + props.landmark?.latitude
            + "\n\tLandmark type: " + props.landmark?.landmark_type
            :
            "Report submitted for a comment on landmark " + props.comment?.landmark
            + '\n\tComment: "' + props.comment?.content + '"'
        report += "\nReason(s) for report: \n\t"
        for (let i = 0; i < selectedReasons.length; i++) {
            var tempItem = reasons.find(item => item.value === selectedReasons[i]).label
            console.log(tempItem)
            report += tempItem + ((i == selectedReasons.length - 1) ? "\n" : "\n\t")
        }
        text ? report += "Extra comments: " + text : null
        console.log(report)
        // props.reportLandmark(report)
        Alert.alert('Report submitted', 'Thank you for making The Atlas a safer place!')
        setModalVisible(!modalVisible)
        // console.log((landmarkOwnedByUser(props.landmark)))
    }

    const [modalVisible, setModalVisible] = useState(false)
    const [text, onChangeText] = React.useState('')
    const [selectedReasons, setSelectedReasons] = useState([])

    const reasons = props.isLandmark ?
        [
            { value: '92iijs7yta', label: 'Landmark does not exist' },
            { value: 'hsyasajs', label: 'Inaccurate tag' },
            { value: 'a0s0a8ssbsd', label: 'Spam' },
            { value: '16hbajsabsd', label: 'Sexually explicit material' },
            { value: 'nahs75a5sg', label: 'Hate speech or symbols' },
            { value: '667atsas', label: 'Promotion of violence' },
        ]
        :
        [
            { value: '92iijs7ytb', label: 'Misinformation' },
            { value: 'a0s0a8ssbse', label: 'Spam' },
            { value: '16hbajsabse', label: 'Sexually explicit material' },
            { value: 'nahs75a5sh', label: 'Hate speech or symbols' },
            { value: '667atsat', label: 'Promotion of violence' },
            { value: 'hsyasajt', label: 'Harassment or bullying' },
            { value: 'djsjudksje', label: 'Impersonation' }
        ]

    const onSelectedReasonsChange = (selectedReasons) => {
        setSelectedReasons(selectedReasons)
        for (let i = 0; i < selectedReasons.length; i++) {
            var tempItem = reasons.find(item => item.value === selectedReasons[i])
        }
    }

    return (
        <View>
            <TouchableOpacity onPress={toggleModal}>
                <View>
                    {props.isLandmark ?
                        <FontAwesome style={{ marginLeft: 5, marginTop: 2, marginRight: 10 }} color="white" size={25} name="flag" />
                        :
                        <FontAwesome style={{ paddingTop: 1, marginLeft: 20 }} color="red" size={25} name="flag" />
                    }
                </View>
            </TouchableOpacity>
            <Modal
                backdropTransitionOutTiming={0}
                hideModalContentWhileAnimating={true}
                isVisible={modalVisible}
                animationIn={'slideInUp'}
                animationOut={'slideOutDown'}
                useNativeDriver={true}
                useNativeDriverForBackdrop={true}
                onBackdropPress={() => setModalVisible(false)}>
                <View style={styles.modalView}>
                    <View style={{ width: '100%' }}>
                        {props.isLandmark ?
                            <Text style={styles.modalText}>Report Landmark</Text>
                            :
                            <Text style={styles.modalText}>Report Comment</Text>
                        }
                        <View style={{ justifyContent: 'flex-start' }}>
                            <Text style={{ marginRight: 10, marginBottom: 5 }}>Reason(s) for reporting:</Text>
                            <View style={{ alignSelf: 'stretch', borderColor: "blue", borderWidth: 0, width: '100%', justifyContent: 'center' }}>
                                <Select
                                    styleRowList={{ borderColor: "red", borderWidth: 0 }}
                                    textColor='black'
                                    itemTextColor='black'
                                    items={reasons}
                                    displayKey="label"
                                    uniqueKey="value"
                                    submitButtonText="Confirm"
                                    submitButtonColor='black'
                                    onSelectedItemsChange={onSelectedReasonsChange}
                                    selectedItems={selectedReasons}>
                                </Select>
                            </View>
                        </View>
                        <TextInput
                            style={styles.input}
                            onChangeText={onChangeText}
                            value={text}
                            placeholder="Other comments..."
                            keyboardType="default"
                        />
                    </View>
                    {!keyboardIsVisible && <View style={{ flexDirection: 'row' }}>
                        <Pressable
                            style={styles.cancel}
                            onPress={toggleModal}>
                            <Text style={{ color: 'white', textAlign: 'center' }}>Cancel</Text>
                        </Pressable>
                        <Pressable
                            style={styles.submit}
                            onPress={() =>
                                Alert.alert(
                                    'Are you sure you want to submit this report?',
                                    'This action cannot be undone.',
                                    [
                                        { text: 'Cancel', onPress: () => console.log('Report cancelled'), style: 'cancel' },
                                        { text: 'OK', onPress: sendReport },
                                    ],
                                    { cancelable: false }
                                )}>
                            <Text style={{ color: 'white', textAlign: 'center' }}>Submit</Text>
                        </Pressable>
                    </View>}
                </View>
            </Modal>
        </View>
    )
}

const styles = StyleSheet.create({
    modalView: {
        flex: 1,
        justifyContent: 'space-between',
        alignSelf: 'stretch',
        margin: 20,
        backgroundColor: 'white',
        borderRadius: 20,
        padding: 35,
        alignItems: 'center',
        shadowColor: '#000',
        shadowOffset: {
            width: 0,
            height: 2,
        },
        shadowOpacity: 0.25,
        shadowRadius: 4,
        elevation: 5,
    },
    modalText: {
        marginBottom: 15,
        textAlign: 'center',
    },
    input: {
        height: 40,
        margin: 12,
        marginTop: 60,
        borderWidth: 1,
        borderRadius: 10,
        padding: 10,
    },
    cancel: {
        width: 100,
        height: 40,
        margin: 12,
        borderWidth: 1,
        borderRadius: 10,
        borderColor: 'white',
        padding: 10,
        backgroundColor: '#df3f3f',
        color: 'white'
    },
    submit: {
        width: 100,
        height: 40,
        margin: 12,
        borderWidth: 1,
        borderRadius: 10,
        borderColor: 'white',
        padding: 10,
        backgroundColor: '#3fafdf',
        color: 'white'
    }
})